Unnamed repository; edit this file 'description' to name the repository.
fix: rename schema subItems with sub_items
A4-Tacks 7 weeks ago
parent c5fba38 · commit 80d2e35
-rw-r--r--crates/rust-analyzer/src/config.rs4
-rw-r--r--docs/book/src/configuration_generated.md2
-rw-r--r--editors/code/package.json4
3 files changed, 5 insertions, 5 deletions
diff --git a/docs/book/src/configuration_generated.md b/docs/book/src/configuration_generated.md
index 7bbb9e0258..bc5ef9e96c 100644
--- a/docs/book/src/configuration_generated.md
+++ b/docs/book/src/configuration_generated.md
@@ -446,7 +446,7 @@ verbose form `{ "path": "path::to::item", type: "always" }`.
For traits the type "methods" can be used to only exclude the methods but not the trait
itself.
-For modules the type "subItems" can be used to only exclude the all items in it but not the module
+For modules the type "sub_items" can be used to only exclude the all items in it but not the module
itself. This does not include items defined in nested modules.
This setting also inherits `#rust-analyzer.completion.excludeTraits#`.
diff --git a/editors/code/package.json b/editors/code/package.json
index 8df606d4c4..9ca1e80c6a 100644
--- a/editors/code/package.json
+++ b/editors/code/package.json
@@ -1328,7 +1328,7 @@
"title": "Completion",
"properties": {
"rust-analyzer.completion.autoimport.exclude": {
- "markdownDescription": "A list of full paths to items to exclude from auto-importing completions.\n\nTraits in this list won't have their methods suggested in completions unless the trait\nis in scope.\n\nYou can either specify a string path which defaults to type \"always\" or use the more\nverbose form `{ \"path\": \"path::to::item\", type: \"always\" }`.\n\nFor traits the type \"methods\" can be used to only exclude the methods but not the trait\nitself.\n\nFor modules the type \"subItems\" can be used to only exclude the all items in it but not the module\nitself. This does not include items defined in nested modules.\n\nThis setting also inherits `#rust-analyzer.completion.excludeTraits#`.",
+ "markdownDescription": "A list of full paths to items to exclude from auto-importing completions.\n\nTraits in this list won't have their methods suggested in completions unless the trait\nis in scope.\n\nYou can either specify a string path which defaults to type \"always\" or use the more\nverbose form `{ \"path\": \"path::to::item\", type: \"always\" }`.\n\nFor traits the type \"methods\" can be used to only exclude the methods but not the trait\nitself.\n\nFor modules the type \"sub_items\" can be used to only exclude the all items in it but not the module\nitself. This does not include items defined in nested modules.\n\nThis setting also inherits `#rust-analyzer.completion.excludeTraits#`.",
"default": [
{
"path": "core::borrow::Borrow",
@@ -1356,7 +1356,7 @@
"enum": [
"always",
"methods",
- "subItems"
+ "sub_items"
],
"enumDescriptions": [
"Do not show this item or its methods (if it is a trait) in auto-import completions.",
diff --git a/crates/rust-analyzer/src/config.rs b/crates/rust-analyzer/src/config.rs
index 6f532e4224..74ba183f97 100644
--- a/crates/rust-analyzer/src/config.rs
+++ b/crates/rust-analyzer/src/config.rs
@@ -662,7 +662,7 @@ config_data! {
/// For traits the type "methods" can be used to only exclude the methods but not the trait
/// itself.
///
/// For modules the type "subItems" can be used to only exclude the all items in it but not the module
/// itself. This does not include items defined in nested modules.
///
/// This setting also inherits `#rust-analyzer.completion.excludeTraits#`.
@@ -4135,7 +4135,7 @@ fn field_props(field: &str, ty: &str, doc: &[&str], default: &str) -> serde_json
},
"type": {
"type": "string",
- "enum": ["always", "methods", "subItems"],
+ "enum": ["always", "methods", "sub_items"],
"enumDescriptions": [
"Do not show this item or its methods (if it is a trait) in auto-import completions.",
"Do not show this trait's methods in auto-import completions.",
@@ -662,7 +662,7 @@ config_data! {
/// itself.
///
- /// For modules the type "subItems" can be used to only exclude the all items in it but not the module
+ /// For modules the type "sub_items" can be used to only exclude the all items in it but not the module
/// itself. This does not include items defined in nested modules.
///